==> peony-extensions_4.10.0.0.orig.tar.gz: peony-extensions-4.10.0.0/peony-engrampa-menu-plugin/translations/peony-engrampa-menu_kk_KZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kk">
<context>
    <name>Peony::EngrampaMenuPlugin</name>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="66"/>
        <source>compress...</source>
        <translation>сығымдағыш...</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="82"/>
        <source>uncompress to current path</source>
        <translation>ағымдағы жолға ығыспау</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="93"/>
        <source>uncompress to specific path...</source>
        <translation>нақты жолға ығыспау...</translation>
    </message>
    <message>
        <source>uncompress to specific path</source>
        <translation type="vanished">解压缩到...</translation>
    </message>
    <message>
        <source>Peony-Qt KArchive Menu Extension</source>
        <translation type="vanished">文件压缩插件</translation>
    </message>
    <message>
        <source>KArchive Menu Extension.</source>
        <translation type="vanished">压缩菜单扩展。</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.h" line="40"/>
        <source>Peony-Qt engrampa Extension</source>
        <translation>Peony-Qt энгрампа кеңейтімі</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.h" line="41"/>
        <source>engrampa Menu Extension.</source>
        <translation>engrampa мәзірін кеңейту.</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.20.0.0.orig.tar.gz: peony-extensions-4.20.0.0/peony-engrampa-menu-plugin/translations/peony-engrampa-menu_kk_KZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kk">
<context>
    <name>Peony::EngrampaMenuPlugin</name>
    <message>
        <source>compress...</source>
        <translation type="vanished">сығымдағыш...</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="74"/>
        <source>compress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="90"/>
        <source>uncompress to current path</source>
        <translation>وسى جايغا نىعىزداۋ</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="101"/>
        <source>uncompress to specific path...</source>
        <translation>عا نىعىزداۋ....</translation>
    </message>
    <message>
        <source>uncompress to specific path</source>
        <translation type="vanished">解压缩到...</translation>
    </message>
    <message>
        <source>Peony-Qt KArchive Menu Extension</source>
        <translation type="vanished">文件压缩插件</translation>
    </message>
    <message>
        <source>KArchive Menu Extension.</source>
        <translation type="vanished">压缩菜单扩展。</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.h" line="40"/>
        <source>Peony-Qt engrampa Extension</source>
        <translation>نىعىزداۋ قوسىمشا سەستيما حۇجاتى</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.h" line="41"/>
        <source>Engrampa Menu Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>engrampa Menu Extension.</source>
        <translation type="vanished">engrampa мәзірін кеңейту.</translation>
    </message>
</context>
</TS>
